import {
  json,
  tree,
  hierarchy,
  linkVertical,
  zoom,
  event,
} from 'd3';

const svg = d3.select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

const margin = { top: 0, right: 50, bottom: 0, left: 75 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree().size([innerHeight, innerWidth]);

const zoomG = svg
  .attr('width', width)
  .attr('height', height)
  .append('g');

const g = zoomG
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

svg.call(
  zoom().on('zoom', () => {
    zoomG.attr('transform', event.transform);
  }),
);

json('data.json').then((data) => {
  const root = hierarchy(data);
  const links = treeLayout(root).links();
  const linkPathGenerator = linkVertical()
    .x((d) => d.x)
    .y((d) => d.y);

  g.selectAll('path')
    .data(links)
    .enter()
    .append('path')
    .attr('d', linkPathGenerator);

  const subg = g.selectAll('g')
    .data(root.descendants())
    .enter()
    .append('g')
subg
  .append('foreignObject')
    .attr('x',d=>d.x)
    .attr('y',d=>d.y)
    .attr('width',"100")
    .attr('height',"100")
    .append('input')
    // .attr('type',"checkbox");
  subg
    .append('text')
    .attr('x', (d) => d.x)
    .attr('y', (d) => d.y)
    .attr('dy', '0.32em')
    .attr('text-anchor', (d) =>
      d.children ? 'middle' : 'start',
    )
    // .attr('font-size', (d) => 3.25 - d.depth + 'em')
    .text((d) => d.data.name);
});






